
# Class: CompoundDtype




URI: [nwb_schema_language:CompoundDtype](https://w3id.org/p2p_ld/nwb-schema-language/CompoundDtype)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[CompoundDtype&#124;name:string;doc:string;dtype:string%20%2B])](https://yuml.me/diagram/nofunky;dir:TB/class/[CompoundDtype&#124;name:string;doc:string;dtype:string%20%2B])

## Referenced by Class


## Attributes


### Own

 * [CompoundDtype➞name](CompoundDtype_name.md)  <sub>1..1</sub>
     * Range: [String](types/String.md)
 * [doc](doc.md)  <sub>1..1</sub>
     * Description: Description of corresponding object.
     * Range: [String](types/String.md)
 * [CompoundDtype➞dtype](CompoundDtype_dtype.md)  <sub>1..\*</sub>
     * Range: [String](types/String.md)
